@@ -14,12 +14,13 @@ bmin<-1
 for (a in 0:(r0-1)){
 	row.num <-row.num+1
 	keep.doing.b.loop<-TRUE
+      # Note: there is much room for efficiency gains here: take out b loop, use vector for b, perhaps use break(), 
 	for (b in bmin:r1){
 		if (keep.doing.b.loop==TRUE && Bvalue(M=m,i=a+b,w=b,P=alpha) >= qnorm(1-e1) ){
 			theta[row.num,1]<- b
 			theta[row.num,2]<- a+b
 			bmin<-b
-			keep.doing.b.loop<-F
+			keep.doing.b.loop<-FALSE
 		}
 		if (keep.doing.b.loop==TRUE && b==r1){
 			theta[row.num,1]<- b
@@ -38,7 +39,7 @@ for (b in 0:(r1-1)){
 			theta[row.num,1]<- b
 			theta[row.num,2]<- a+b
 			amin<-a
-			keep.doing.a.loop<-F
+			keep.doing.a.loop<-FALSE
 		}
 		if (keep.doing.a.loop==TRUE && a==r0){
 			theta[row.num,1]<- b
